==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/MagnifyingGlassArrowRight.md <==
# MagnifyingGlassArrowRight


```text
fontawesome-6/Solid/MagnifyingGlassArrowRight
```

```text
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')
```



| Illustration | MagnifyingGlassArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MagnifyingGlassArrowRight.png) | ![illustration for MagnifyingGlassArrowRight](../../fontawesome-6/Solid/MagnifyingGlassArrowRight.Local.png) |




## MagnifyingGlassArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassArrowRight
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')

' renders the element
MagnifyingGlassArrowRight('MagnifyingGlassArrowRight', 'Magnifying Glass Arrow Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassArrowRight
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')

' renders the element
MagnifyingGlassArrowRight('MagnifyingGlassArrowRight', 'Magnifying Glass Arrow Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/MagnifyingGlassArrowRight.md <==
# MagnifyingGlassArrowRight


```text
fontawesome-6/Solid/MagnifyingGlassArrowRight
```

```text
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')
```



| Illustration | MagnifyingGlassArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MagnifyingGlassArrowRight.png) | ![illustration for MagnifyingGlassArrowRight](../../fontawesome-6/Solid/MagnifyingGlassArrowRight.Local.png) |




## MagnifyingGlassArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassArrowRight
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')

' renders the element
MagnifyingGlassArrowRight('MagnifyingGlassArrowRight', 'Magnifying Glass Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassArrowRight
include('fontawesome-6/Solid/MagnifyingGlassArrowRight')

' renders the element
MagnifyingGlassArrowRight('MagnifyingGlassArrowRight', 'Magnifying Glass Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```
